@@ -16,6 +16,7 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 import copy
+import os
 import threading
 import time
 from functools import wraps
@@ -27,10 +28,13 @@ from lxml import etree, html
 from requests.structures import CaseInsensitiveDict
 
 import apiritif
+from apiritif.ssl_adapter import SSLAdapter
 from apiritif.thread import get_from_thread_store, put_into_thread_store
 from apiritif.utilities import *
 from apiritif.utils import headers_as_text, assert_regexp, assert_not_regexp, log, get_trace
 
+BODY_LIMIT = int(os.environ.get("APIRITIF_TRACE_BODY_EXCLIMIT", "1024"))
+
 
 class TimeoutError(Exception):
     pass
@@ -50,7 +54,7 @@ class http(object):
     @staticmethod
     def request(method, address, session=None,
                 params=None, headers=None, cookies=None, data=None, json=None, files=None,
-                allow_redirects=True, timeout=30):
+                encrypted_cert=None, allow_redirects=True, timeout=30):
         """
 
         :param method: str
@@ -69,6 +73,12 @@ class http(object):
 
         if session is None:
             session = requests.Session()
+
+        if encrypted_cert is not None:
+            certificate_file_path, passphrase = encrypted_cert
+            adapter = SSLAdapter(certificate_file_path=certificate_file_path, passphrase=passphrase)
+            session.mount('https://', adapter)
+
         request = requests.Request(method, address,
                                    params=params, headers=headers, cookies=cookies, json=json, data=data, files=files)
         prepared = session.prepare_request(request)
@@ -435,7 +445,9 @@ class HTTPTarget(object):
                  auto_assert_ok=True,
                  timeout=30,
                  allow_redirects=True,
-                 session=None):
+                 session=None,
+                 cert=None,
+                 encrypted_cert=None):
         self.address = address
         # config flags
         self._base_path = base_path
@@ -730,7 +742,7 @@ class HTTPResponse(object):
         body = self.json()
         matches = jsonpath_expr.find(body)
         if not matches:
-            msg = msg or "JSONPath query %r didn't match response content: %s" % (jsonpath_query, body)
+            msg = msg or "JSONPath query %r didn't match response: %s" % (jsonpath_query, self.text[:BODY_LIMIT])
             raise AssertionError(msg)
         actual_value = matches[0].value
         if expected_value is not None and actual_value != expected_value:
@@ -745,7 +757,7 @@ class HTTPResponse(object):
         body = self.json()
         matches = jsonpath_expr.find(body)
         if matches:
-            msg = msg or "JSONPath query %r did match response content: %s" % (jsonpath_query, body)
+            msg = msg or "JSONPath query %r did match response: %s" % (jsonpath_query, self.text[:BODY_LIMIT])
             raise AssertionError(msg)
         return self
 
@@ -755,7 +767,7 @@ class HTTPResponse(object):
         tree = etree.parse(BytesIO(self.content), parser)
         matches = tree.xpath(xpath_query)
         if not matches:
-            msg = msg or "XPath query %r didn't match response content: %s" % (xpath_query, self.text)
+            msg = msg or "XPath query %r didn't match response content: %s" % (xpath_query, self.text[:BODY_LIMIT])
             raise AssertionError(msg)
         return self
 
@@ -765,7 +777,7 @@ class HTTPResponse(object):
         tree = etree.parse(BytesIO(self.content), parser)
         matches = tree.xpath(xpath_query)
         if matches:
-            msg = msg or "XPath query %r did match response content: %s" % (xpath_query, self.text)
+            msg = msg or "XPath query %r did match response content: %s" % (xpath_query, self.text[:BODY_LIMIT])
             raise AssertionError(msg)
         return self
 
@@ -777,7 +789,7 @@ class HTTPResponse(object):
 
         matches = expected_value in vals if expected_value is not None else vals
         if not matches:
-            msg = msg or "CSSSelect query %r didn't match response content: %s" % (query, self.text)
+            msg = msg or "CSSSelect query %r didn't match response content: %s" % (query, self.text[:BODY_LIMIT])
             raise AssertionError(msg)
         return self
 
@@ -788,7 +800,7 @@ class HTTPResponse(object):
         except AssertionError:
             return self
 
-        msg = msg or "CSSSelect query %r did match response content: %s" % (query, self.text)
+        msg = msg or "CSSSelect query %r did match response content: %s" % (query, self.text[:BODY_LIMIT])
         raise AssertionError(msg)
 
     # TODO: assertTiming? to assert response time / connection time
